//
//  LissajousView.swift
//  Lissajous
//
//  Created by Santiago Pavón Gómez on 7/10/16.
//  Copyright © 2016 UPM. All rights reserved.
//

import UIKit

class LissajousView: UIView {

    // Instantes inicial y final
    let startTime = 0.0
    var endTime = 50.0
    
    // Velocidad Angular Horizontal
    var wHorizontal = 0.4
    
    // Velocidad Angular Vertical
    var wVertical = 0.6
    
    
    override func draw(_ rect: CGRect) {
        
        let path = UIBezierPath()
        
        // Empiezo en el instante final
        let x0 = x(at: startTime)
        let y0 = y(at: startTime)
        path.move(to: CGPoint(x: x0, y: y0))
        
        
        let incrTime = .pi / (wHorizontal + wVertical) / 100

        for t in stride(from: startTime, to: endTime, by: incrTime) {
            // Posicion en el instante t
            let xt = x(at: t)
            let yt = y(at: t)
            path.addLine(to: CGPoint(x: xt, y: yt))
        }
        
        path.lineWidth = 2
        UIColor.purple.set()
        path.stroke()
    }

    
    /// Coordenada X a pintar en el instante de tiempo dado.
    ///
    /// El valor devuelto se adapta para situar el centro del 
    /// eje X en mitad de la pantalla.
    ///
    /// Recordad que el origen de coordenadas de las views
    /// esta situado en la esquina superior izquierda
    ///
    /// - parameter time: Instante de tiempo
    ///
    /// - returns: Coordenada X.
    private func x(at time: Double) -> CGFloat {
        
        let amplitud = bounds.size.width/2

        return amplitud * CGFloat(sin(wHorizontal * time)) + amplitud
    }
    
    
    /// Coordenada Y a pintar en el instante de tiempo dado.
    ///
    /// El valor devuelto se adapta para situar el centro del eje Y 
    /// en mitad de la pantalla y cambiar el sentido del eje.
    ///
    /// Recordad que el origen de coordenadas de las views
    /// esta situado en la esquina superior izquierda
    ///
    /// - parameter time: Instante de tiempo
    ///
    /// - returns: Coordenada Y con el origen .
    private func y(at time: Double) -> CGFloat {
        
        let amplitud = bounds.size.height/2
        
        return amplitud - amplitud * CGFloat(cos(wVertical * time))
    }
    
}
